tlds = {
    "com",
    "co.uk",
    "org",
    "net",
    "ru",
    "eu",
    "de",
    "fr",
    "tv",
    "cn",
    "es",
    "com.tr",
}
domains = {
    "google",
    "youtube",
    "facebook",
    "baidu",
    "wikipedia",
    "qq",
    "tmall",
    "yahoo",
    "taobao",
    "amazon",
    "sohu",
    "twitter",
    "jd",
    "live",
    "vk",
    "instagram",
    "weibo",
    "sina",
    "login",
    "360",
    "reddit",
    "linkedin",
    "blogspot",
    "netflix",
    "microsoftonline",
    "pages",
    "yandex",
    "mail",
    "pornhub",
    "twitch",
    "porn555",
    "csdn",
    "alipay",
    "microsoft",
    "aliexpress",
    "t",
    "ebay",
    "bing",
    "naver",
    "github",
    "stackoverflow",
    "livejasmin",
    "office",
    "msn",
    "imdb",
    "xvideos",
    "whatsapp",
    "tribunnews",
    "wordpress",
    "googleusercontent",
    "paypal",
    "bilibili",
    "apple",
    "xhamster",
    "imgur",
    "xinhuanet",
    "adobe",
    "fandom",
    "babytree",
    "pinterest",
    "fbcdn",
    "dropbox",
    "tumblr",
    "exosrv",
    "hao123",
    "amazonaws",
    "instructure",
    "speakol",
    "booking",
    "zhihu",
    "tianya",
    "soso",
    "thestartmagazine",
    "detail",
    "bbc",
    "salesforce",
    "pixnet",
    "aparat",
    "cnn",
    "onlinesbi",
    "force",
    "rakuten",
    "bodelen",
    "1cnblogs",
}
